==> pointers.py-1.2.7-py3-none-any.whl: pointers/exceptions.py <==
__all__ = ("IsMallocPointerError",
           "AllocationError",
           "NotEnoughChunks",
           "IsFrozenError",
           "DereferenceError",
           "IncorrectItemExpectedForSubscriptError",
           "NotSubscriptableError",
           "CallocSubscriptionDangerError",
           "ImmutableObjectError")  # noqa


class IsMallocPointerError(Exception):
    """Raised when trying perform an operation on a malloc pointer that isn't supported."""  # noqa

    pass


class AllocationError(Exception):
    """Raised when a memory allocation fails."""

    pass


class NotEnoughChunks(Exception):
    """Raised when there aren't enough chunks in a CallocPointer."""

    pass


class IsFrozenError(Exception):
    """Raised when trying to move the address of a frozen pointer."""

    pass


class DereferenceError(Exception):
    """Raised when trying to dereference an object address that doesn't exist."""  # noqa

    pass


class IncorrectItemExpectedForSubscriptError(Exception):
    """Raised when an item subscript method is subscripted with a non-integer value."""  # noqa

    pass


class NotSubscriptableError(Exception):
    """Raised when a Pointer subscript is attempted to a PyObject that is not subscriptable."""  # noqa

    pass


class CallocSubscriptionDangerError(Exception):
    """Raised when attempting to subscript a Calloc chunk. Assignment like this is dangerous at this time."""  # noqa

    pass


class ImmutableObjectError(Exception):
    """Raised when attempting to setting item assignment to immutable objects."""  # noqa

    pass

==> pointers.py-1.2.8-py3-none-any.whl: pointers/exceptions.py <==
__all__ = (
    "IsMallocPointerError",
    "AllocationError",
    "NotEnoughChunks",
    "IsFrozenError",
    "DereferenceError",
    "IncorrectItemExpectedForSubscriptError",
    "NotSubscriptableError",
    "CallocSubscriptionDangerError",
    "ImmutableObjectError",
    "FreedMemoryError",
    "InvalidSizeError",
)  # noqa


class IsMallocPointerError(Exception):
    """Raised when trying perform an operation on a malloc pointer that isn't supported."""  # noqa

    pass


class AllocationError(Exception):
    """Raised when a memory allocation fails."""

    pass


class NotEnoughChunks(Exception):
    """Raised when there aren't enough chunks in a CallocPointer."""

    pass


class IsFrozenError(Exception):
    """Raised when trying to move the address of a frozen pointer."""

    pass


class DereferenceError(Exception):
    """Raised when trying to dereference an object address that doesn't exist."""  # noqa

    pass


class IncorrectItemExpectedForSubscriptError(Exception):
    """Raised when an item subscript method is subscripted with a non-integer value."""  # noqa

    pass


class NotSubscriptableError(Exception):
    """Raised when a Pointer subscript is attempted to a PyObject that is not subscriptable."""  # noqa

    pass


class CallocSubscriptionDangerError(Exception):
    """Raised when attempting to subscript a Calloc chunk. Assignment like this is dangerous at this time."""  # noqa

    pass


class ImmutableObjectError(Exception):
    """Raised when attempting to setting item assignment to immutable objects."""  # noqa

    pass


class FreedMemoryError(Exception):
    """Rasied when trying to perform an operation on freed memory."""

    pass


class InvalidSizeError(Exception):
    """Raised when trying to move an object of the wrong size to an allocation."""  # noqa

    pass
